/*
 * Calendar Plus Add-on
 * Copyright (c) 2020 Radical Bridge
 *
 * Licensed under the MIT License
 */

 jQuery.noConflict();
(function($, PLUGIN_ID) {
    "use strict";

    const appId = kintone.app.getId();

	// プラグイン設定の取得
	const config = kintone.plugin.app.getConfig(PLUGIN_ID);
    if (!config || !Object.keys(config).length || !config['enableAddOn']) {
        return false;
    }

    // 一覧画面表示時
    kintone.events.on(['app.record.index.show'], function(event) {
        $('#calendarPlus').after(
            $('<div>').prop('id', 'detail_window').css({
                'position': 'fixed',
                'width': '100%',
                'height': '100%',
                'padding-top': '40px',
                'top': '0px',
                'z-index': '100',
                'text-align': 'center',
                'background-color': 'rgba(0, 0, 0, 0.5)'
            })
        );
        $('#detail_window').hide();

        $('#detail_window').on('click', function() {
            $('#detail_window').hide();
        });

        // カレンダーPlus：イベントレコードクリックによる詳細画面遷移前イベント
        calendarplus.events.on(['cp.event.click'], function(e) {
            let rec = e.record;

            let recId = rec['$id']['value'];
            let detail_url = '/k/' + appId + '/show#record=' + recId;

            $('#detail_window').hide();
            $('#detail_window').empty();
            $('#detail_window').append(
                $('<iframe>').prop('src', detail_url).css({
                    'width': '80%',
                    'height': '80%',
                    'background-color': 'rgb(200, 200, 200)'
                })
            );
            $('#detail_window').show();

            return false;
        });

        // カレンダーPlus：イベントレコードのマウスオーバーイベント
        calendarplus.events.on(['cp.event.mouseover'], function(e) {
            let rec = e.record;
            let $elm = $(e.jsEvent.target);

            let start = rec['開始日時']['value'];
            let end = rec['終了日時']['value'];
            let title = rec['表示用タイトル']['value'] || '';
            let room = rec['会議室']['value'] || '';
            let d_start = luxon.DateTime.fromISO(start).toFormat('HH:mm');
            let d_end = luxon.DateTime.fromISO(end).toFormat('HH:mm');
            let content = d_start + '～' + d_end + '<br />タイトル：' + title + '<br />会議室：' + room;
            tippy($elm.get(0), {
                allowHTML: true,
                content: content
            });
        });

        return event;
    });

})(jQuery, kintone.$PLUGIN_ID);
